# API

## Preprocessing

```{eval-rst}
.. module:: bolero_process.pp
.. currentmodule:: bolero_process

.. autosummary::
    :toctree: generated

    pp.basic_preproc
```

## Tools

```{eval-rst}
.. module:: bolero_process.tl
.. currentmodule:: bolero_process

.. autosummary::
    :toctree: generated

    tl.basic_tool
```

## Plotting

```{eval-rst}
.. module:: bolero_process.pl
.. currentmodule:: bolero_process

.. autosummary::
    :toctree: generated

    pl.basic_plot
    pl.BasicClass
```
